@@ -6,7 +6,7 @@ test_that("sessionisation handles zero-event entries", {
   events <- list()
   
   #Test resulting value
-  expect_that(length(sessionise(events)), equals(0))
+  expect_that(length(reconstruct_sessions(events)), equals(0))
   
 })
 
@@ -16,7 +16,7 @@ test_that("sessionisation handles single-event entries", {
   events <- list(1)
   
   #Test resulting value
-  expect_that(length(sessionise(events)), equals(1))
+  expect_that(length(reconstruct_sessions(events)), equals(1))
   
 })
 
@@ -26,7 +26,7 @@ test_that("sessionisation handles multi-set entries", {
   events <- list(1,2)
   
   #Test resulting value
-  expect_that(length(sessionise(events)), equals(2))
+  expect_that(length(reconstruct_sessions(events)), equals(2))
   
 })
 
@@ -34,7 +34,7 @@ test_that("sessionisation handles thresholds", {
   
   #Example set and run
   events <- list(c(1,2,3,12,5),2)
-  results <- sessionise(events,6)
+  results <- reconstruct_sessions(events,6)
   
   #Test resulting value
   expect_that(length(results), equals(3))
